@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2019 Free Software Foundation, Inc.
+   Copyright (C) 1999-2020 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -225,7 +225,8 @@ extern int imap4d_argc;
 extern char **imap4d_argv;
 extern jmp_buf child_jmp;
 extern struct mu_tls_config global_tls_conf;
-  
+extern int global_tls_mode;
+
 extern int test_mode;
 extern int silent_expunge;
 
@@ -345,6 +346,7 @@ extern int  imap4d_select_status (void);
 extern int  imap4d_starttls (struct imap4d_session *,
 			     struct imap4d_command *, imap4d_tokbuf_t);
 int starttls_init (mu_m_server_t msrv);
+int starttls_server_check (struct imap4d_srv_config *cfg, char const *srvid);
 void tls_encryption_on (struct imap4d_session *);
 extern int  imap4d_status (struct imap4d_session *,
 			   struct imap4d_command *, imap4d_tokbuf_t);
@@ -467,9 +469,6 @@ int is_atom (const char *s);
 int util_isdelim (const char *str);
 int util_trim_nl (char *s, size_t len);
 
-void unistr_downcase (char const *input, char **output);
-int unistr_is_substring (char const *haystack, char const *needle);
-
 int set_xscript_level (int xlev);
 void xscript_declare_client_payload (size_t len);
 
